==> meteor-react-materializecss-1.0.27.tgz: package/src/i18n/sk.js <==
export default {
    "_locale": "sk-SK",
    "simpleSchema": {
        "required": "{{label}} je povinné",
        "minString": "{{label}} musí mať najmenej {{min}} znakov",
        "maxString": "{{label}} nemôže presahovať {{max}} znakov",
        "minNumber": "{{label}} musí byť najmenej {{min}}",
        "maxNumber": "{{label}} nesmie presahovať {{max}}",
        "minNumberExclusive": "{{label}} musí byť väčšie ako {{min}}",
        "maxNumberExclusive": "{{label}} musí byť menšie ako {{max}}",
        "minDate": "{{label}} musí byť v deň alebo po {{min}}",
        "maxDate": "{{label}} musí byť po {{max}}",
        "badDate": "{{label}} nie je platný dátum",
        "minCount": "Musíte zadať najmenej {{minCount}} hodnôt",
        "maxCount": "Nemôžete zadať viac, ako {{maxCount}} hodnôt",
        "noDecimal": "{{label}} musí byť celé číslo",
        "notAllowed": "{{value}} nie je povolená hodnota",
        "expectedType": "{{label}} must be of type {{dataType}}",
        "expectedString": "{{label}} musí byť text",
        "expectedNumber": "{{label}} musí byť číslo",
        "expectedBoolean": "{{label}} musí byť logická hodnota",
        "expectedArray": "{{label}} musí byť pole",
        "expectedObject": "{{label}} musí byť objekt",
        "expectedConstructor": "{{label}} musí byť {{type}}",
        "keyNotInSchema": "{{key}} nie je povolená schémou",
        "idNotFound": "ID {{label}} neexistuje",
        "wrongUnit": "Neplatná {{label}} {{value}}",
        "wrongRola": "{{label}} je nesprávna",
        "wrongConfirmPassw": "Heslo a kontrola hesla musí byť rovnaká",
        "regEx": {
            "msg": "{{label}} zlyhala validácia regulárneho výrazu",
            "email": "{{label}} musí byť platná e-mailová adresa",
            "weakEmail": "{{label}} musí byť platná e-mailová adresa",
            "domain": "{{label}} musí byť platná doména",
            "weakDomain": "{{label}} musí byť platná doména",
            "ip": "{{label}} musí byť platná IPv4 alebo IPv6 adresa",
            "ipV4": "{{label}} musí byť platná IPv4 adresa",
            "ipV6": "{{label}} musí bt platná IPv6 adresa",
            "url": "{{label}} musí byť platná URL",
            "id": "{{label}} musí byť platné alfanumerické ID"
        }
    },
    "messages": {
        "back": "späť",
        "search": "Hľadať",
        "save": "Uložiť",
        "save_error": "Chyba pri uložení",
        "error": "Chyba",
        "no_connection": "Nie je pripojenie na internet!",
        "records_count": "počet záznamov",
        "yes": "Áno",
        "no": "Nie",
        "delete_title": "Vymazať záznam",
        "delete": "Vymazať",
        "delete_error": "Chyba pri vymazaní",
        "insert": "Pridať",
        "show": "Zobraziť",
        "cancel": "Zrušiť",
        "select_columns": "Výber stĺpcov"
    }
}

==> meteor-react-materializecss-1.0.32.tgz: package/src/i18n/sk.js <==
export default {
    "_locale": "sk-SK",
    "simpleSchema": {
        "required": "{{label}} je povinné",
        "minString": "{{label}} musí mať najmenej {{min}} znakov",
        "maxString": "{{label}} nemôže presahovať {{max}} znakov",
        "minNumber": "{{label}} musí byť najmenej {{min}}",
        "maxNumber": "{{label}} nesmie presahovať {{max}}",
        "minNumberExclusive": "{{label}} musí byť väčšie ako {{min}}",
        "maxNumberExclusive": "{{label}} musí byť menšie ako {{max}}",
        "minDate": "{{label}} musí byť v deň alebo po {{min}}",
        "maxDate": "{{label}} musí byť po {{max}}",
        "badDate": "{{label}} nie je platný dátum",
        "minCount": "Musíte zadať najmenej {{minCount}} hodnôt",
        "maxCount": "Nemôžete zadať viac, ako {{maxCount}} hodnôt",
        "noDecimal": "{{label}} musí byť celé číslo",
        "notAllowed": "{{value}} nie je povolená hodnota",
        "expectedType": "{{label}} must be of type {{dataType}}",
        "expectedString": "{{label}} musí byť text",
        "expectedNumber": "{{label}} musí byť číslo",
        "expectedBoolean": "{{label}} musí byť logická hodnota",
        "expectedArray": "{{label}} musí byť pole",
        "expectedObject": "{{label}} musí byť objekt",
        "expectedConstructor": "{{label}} musí byť {{type}}",
        "keyNotInSchema": "{{key}} nie je povolená schémou",
        "idNotFound": "ID {{label}} neexistuje",
        "wrongUnit": "Neplatná {{label}} {{value}}",
        "wrongRola": "{{label}} je nesprávna",
        "wrongConfirmPassw": "Heslo a kontrola hesla musí byť rovnaká",
        "regEx": {
            "msg": "{{label}} zlyhala validácia regulárneho výrazu",
            "email": "{{label}} musí byť platná e-mailová adresa",
            "weakEmail": "{{label}} musí byť platná e-mailová adresa",
            "domain": "{{label}} musí byť platná doména",
            "weakDomain": "{{label}} musí byť platná doména",
            "ip": "{{label}} musí byť platná IPv4 alebo IPv6 adresa",
            "ipV4": "{{label}} musí byť platná IPv4 adresa",
            "ipV6": "{{label}} musí bt platná IPv6 adresa",
            "url": "{{label}} musí byť platná URL",
            "id": "{{label}} musí byť platné alfanumerické ID"
        }
    },
    "messages": {
        "back": "späť",
        "search": "Hľadať",
        "save": "Uložiť",
        "save_error": "Chyba pri uložení",
        "error": "Chyba",
        "no_connection": "Nie je pripojenie na internet!",
        "records_count": "počet záznamov",
        "yes": "Áno",
        "no": "Nie",
        "delete_title": "Vymazať záznam",
        "delete": "Vymazať",
        "delete_error": "Chyba pri vymazaní",
        "insert": "Pridať",
        "show": "Zobraziť",
        "cancel": "Zrušiť",
        "select_columns": "Výber stĺpcov",
        "view": "Náhľad"
    }
}
